/* TOP MENU LAYOUT */

/*
Copyright (C) 2009 Søren Hauberg <soren@hauberg.org>
Copyright (C) 2015 Oliver Heimlich <oheim@posteo.de>
Copyright (C) 2016 Julien Bect <julien.bect@centralesupelec.fr>

You can redistribute this program and/or modify it under the terms
of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any
later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, see <http://www.gnu.org/licenses/>.
*/

div.menu {
    /*background: #8fb171;*/ /* Green3 */
    /*background: #6d8861;*/ /* Green2 */
    /*background: #577749;*/ /* Green */
	/*background: #8789a5;*/ /* Purple */
    /*background: #ff6600;*/ /* Bright orange */
	/*background: #ea5224;*/ /* Orange */
	/*background: #ea9024;*/ /* Puke yellow */
	background: #729fcf;
	/*background: white;*/
	color: black;
	width: 100%;
	/* position: fixed;*/
	position: absolute;
	top: 0px;
	left: 0px;
	padding-bottom: 0em;
	z-index: 3;
	/*text-align: center;*/
}

table.menu {
    border: none;
    /* border-style: hidden; */
    width: 100%;
    height: 4em;
    padding-left: 2em;
    padding-right: 0em;
    padding-top: 0.5em;
    padding-bottom: 0em;
    color: #363636;
    background-color: inherit;
}
td.menu {
    border: none;
}
a.menu {
	text-decoration: none;
	color: black;
	background-color: inherit;
	font-size: 80%;
}
a.menu:visited {
    color: black;
    background-color: inherit;
}
a.menu:link {
    color: black;
    background-color: inherit;
}
a.menu:hover {
    text-decoration: underline;
}
big.menu {
  font-style: normal;
  font-size: 120%;
  letter-spacing: 0.1em;
  line-height: 1.2em;
  font-weight: bold;
}
small.menu {
    font-style: italic;
    font-size: 80%;
}

/* END TOP MENU LAYOUT */

/* Regular elements */
body {
  background: white;
  color: black;
  font-family: sans-serif;
  font-weight: normal;
  font-size: medium;
  min-width: 500px;
  max-width: 950px;
  margin-left: 0em;
  margin-right: 0em;
  margin-top: 0em;
}


a:link {
  background-color: inherit;
  /*color: #4e9a06;*/
  color: black;
}

a:visited {
  background-color: inherit;
  /*color: #73d216;*/
  color: black;
}

/* Layout of packages page */
div.func {
  margin-left: 1em;
}

h3.package_name {
  background-color: #eeeeec;
  border: 2px solid #d3d7cf;
  padding: 2px;
}
/* the navigation choices at the bottom of the page. */

div#nav {
  background: white;
  color: black;
  float: left;
  font-family: sans-serif;
  font-size: 0.8em;
  margin: 1em 0 0 1em;
  padding: 1px;
  position: fixed;
  /*text-align: left;*/
  width: 10em;
}

div#nav a {
  background-color: #73d216;
  border: 1px solid;
  border-color: #4e9a06;
  display: block;
  padding: 0.2em 0.5em 0.2em 0.5em ;
  text-decoration: none;
  color: black;
}

div#nav a:hover {
  background-color: #4e9a06;
  color: inherit;
}

div#nav div#currentnav {
  background-color: #ccccdd;
  border: 1px solid;
  border-color: #4e9a06;
  display: block;
  padding: 0.2em 0.5em 0.2em 0.5em ;
  text-decoration: none;
  color: black;
  text-align: right;
}

/* the navigation choices for function reference. */

div#nav2 {
  float: right;
  background-color: #73d216;
  color: black;
  padding: 3px;
}

td.alpha_table {
  border: 2px solid #d3d7cf;
  background-color: #eeeeec;
  text-align: center;
  padding: 1em;
}

a.alpha_table {
  font-weight: bold;
  text-decoration: none;
}

/* The style for the function reference sections */
.func {
  background-color: inherit;
  color: inherit;
  text-align: left;
  display: block;
  float: left;
}

.flink {
  background-color: inherit;
  color: inherit;
  text-align: right;
  display: block;
  float: right;
}

.ftext {
  margin-left: 5ex;
  margin-bottom: 2ex;
  clear: both;
}

/* the page content */

#content, #packagedoccontent {
  display: block;
  position: absolute;
  margin-left: 6em;
  /*margin-right: 8em;*/
  margin-top: 4.5em;
  padding-top: 1em;
  width: 70%;
}
#doccontent {
  position: absolute;
  float: left;
  padding-left: 18em;
  padding-top: 1em;
  margin-top: 4.5em;
  margin-right: 4em;
  z-index: 1;
  width: 70%;
}

div#sf_logo {
  text-align: right;
  float: right;
}

/* NEWS FLASH */
h2.flash {
  font-style: normal;
  font-size: 120%;
  letter-spacing: 0.1em;
  line-height: 1.2em;
  font-weight: bold;
  color: black;
  background-color: inherit;
}
div.flash {
    border: solid 3px black;
    width: 70%;
    color: black;
    background: #fcaf3e; /* Orange */
    padding: 0.3em;
}
/* END NEWS FLASH */


/* the title bar */

div#title {
  width: 100%;
  clear: both;
  position: fixed;
  top: 0;
}

div#title h1 {
  background-color: #ffffff;
  border-bottom: 4px solid #73d216;
  font-size: xx-large;
  color: #73d216;
  padding: 0;
  margin: 0;
}

/* The blue title bar on non-main pages */

/*
.header {
  color: #ffffff;
  background-color: #10a0ff;
  font-family: arial,sans-serif;
  padding: 0;
  font-size: medium;
  font-weight: bold;
  border: 3px solid #10a0ff;
}
*/

/* Changes for Octave Wiki */

/*
h1 {
  background-color: #3465a4;
  color: #ffffff;
  font-size: xx-large;
  padding: 2em;
  margin: 8em;
}
*/

h3.question {
  font-size: small;
}

h4, h5, h6 {
  background-color: inherit;
  color: #3465a4;
  font-size: large;
  padding: 2px;
  margin-top: 5px;
}

/*
code {
  padding: 1px;
  margin-left: 1em;
  border: 1px solid;
  border-color: #babdb6;
  background-color: #d3d7cf;
  color: black;
}
*/

table#main_package_table {
  background-color: #d3d7cf;
  color: inherit;
  border: 1px solid;
  border-color: #babdb6;
  margin: 1em 0 0;
  padding: 0.2em 0.5em 0.2em 0.2em;
  text-decoration: none;
}

td.package_table {
  padding-right: 1.5em;
}

div#description_box {
  padding-top: 1em;
}

div.package {
  margin-top: 0.2em;
  background-color: #d3d7cf;
  border: 1px solid;
  border-color: #babdb6;
  padding: 0.2em 0.2em 0;
  color: black;
}

a.package_head_link {
  background-color: inherit;
  color: black;
  text-decoration: none;
}

table.package {
  table-layout: fixed;
  width: 100%;
}

p.package_link a {
  background-color: inherit;
  color: black;
  text-decoration: none;
}

div.see_also {
  background: #EEEEEC;
  border: solid 2px #babdb6;
  padding: 2px;
}

dt {
  font-weight: bold;
  padding-top: 1em;
}

/* Documentation left menu */
#left-menu {
  display: none;

  color: black;
  border: none;
  position: fixed;
  /*position: absolute;*/
  float: left;
  top: 4em;
  left: 0em;
  width: 15em;
  bottom: 0em;
	
  background: #EEEEEC;
  padding-left: 1em;
  padding-top: 1.5em;
  padding-bottom: 0.5em;
  border-left: solid 2px;
  border-right: solid 2px;
  border-bottom: solid 2px;
  border-top: none;
  margin: -2px;
  z-index: 2;
}

p.left-menu {
  margin-top: 0.5em;
  margin-bottom: 0.5em;
}

a.left-menu-link {
  text-decoration: none;
}

ul.left-menu-list {
  list-style: none;
  text-indent: -2em;
  margin-top: -0.5em;
}

/* Headers in the function reference */
h3.category {
    background: #EEEEEC;
    border: solid 2px #babdb6;
    padding: 4px;
}

/* Doxygen stylesheet */

DIV.tabs
{
   float            : left;
   width            : 100%;
   margin-bottom    : 4px;
}

DIV.tabs UL
{
   margin           : 0px;
   padding-left     : 10px;
   list-style       : none;
}

DIV.tabs LI, DIV.tabs FORM
{
   display          : inline;
   margin           : 0px;
   padding          : 0px;
}

DIV.tabs FORM
{
   float            : right;
}

DIV.tabs A
{
   float            : left;
   border-bottom    : 2px solid #d3d7cf;
   font-size        : x-small;
   font-weight      : bold;
   text-decoration  : none;
}

DIV.tabs A:hover
{
   background-position: 100% -150px;
}

DIV.tabs A:link, DIV.tabs A:visited,
DIV.tabs A:active, DIV.tabs A:hover
{
       color: black;
       background-color: inherit;
}

DIV.tabs SPAN
{
   float            : left;
   display          : block;
   padding          : 5px 9px;
   white-space      : nowrap;
}

DIV.tabs INPUT
{
   float            : right;
   display          : inline;
   font-size        : 1em;
}

DIV.tabs TD
{
   font-size        : x-small;
   font-weight      : bold;
   text-decoration  : none;
}



/* Commented Backslash Hack hides rule from IE5-Mac \*/
DIV.tabs SPAN {float : none;}
/* End IE5-Mac hack */

DIV.tabs A:hover SPAN
{
   background-position: 0% -150px;
}

DIV.tabs LI#current A
{
   background-position: 100% -150px;
   border-width     : 0px;
}

DIV.tabs LI#current SPAN
{
   border-top       : 2px solid #d3d7cf;
   border-right     : 2px solid #d3d7cf;
   border-left      : 2px solid #d3d7cf;
   background-position: 0% -150px;
   padding-bottom   : 5px;
   background       : #eeeeec;
   color	    : black;
}

DIV.nav
{
   background       : none;
   border           : none;
   /* border-bottom    : 2px solid #d3d7cf; */
}
/* End doxygen */

table.images {
  width: 90%;
  border: 2px solid #555753;
  background: #babdb6;
}

th.images {
}

td.images {
  border: 2px solid #555753;
  background: white;
}

img.demo {
  width: 100%;
}

td.box_table {
  padding-right: 5em;
}

div.package_box {
  background: #fce94f;
  border: 2px solid #edd400;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
}

div.package_box_header
{
  font-size: 105%;
  font-weight: bold;
  padding: 0.5em;
  -moz-border-radius-topleft: 10px;
  -webkit-border-radius-topleft: 10px;
  -moz-border-radius-topright: 10px;
  -webkit-border-radius-topright: 10px;
  background: #edd400;
  border: 2px solid #edd400;
}

div.package_box_contents {
  padding: 0.5em;
}

div.download_package {
  background: #8ae234;
  border: 2px solid #73d216;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  padding: 1em;
  font-weight: bold;
}

a.function_reference_link,
a.download_link,
a.homepage_link,
a.repository_link,
a.older_versions_download,
a.package_doc,
a.news_file {
  text-decoration: none;
}

a.older_versions_download {
  font-size: 8pt;
  font-weight: normal;
  text-decoration: none;
}

div.package_function_reference {
  background: #729fcf;
  border: 2px solid #3465a4;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  padding: 1em;
  font-weight: bold;
}

#description_box {
  width: 80%;
}

blockquote {
  margin-left: 0em;
}

p.functionfile {
  margin-left: -1em;
  margin-bottom: -0.8em;
  font-weight: bold;
}

DIV.package_display {
    position: relative;
    display: inline-block;
    vertical-align: top;
    margin-right: 2em;
    margin-bottom: 1em;
    width: 23em;
    padding-left: 108px;
    min-height: 100px;
    text-decoration: none;
}

DIV.package_display > * {
    padding-left: .8em;
}

DIV.package_display IMG {
    display: block;
    position: absolute;
    padding: 0;
    left: 0;
    top: 0;
    width: 100px; height: 100px;
    margin-left: 0;
    margin-right: 1em;
}

DIV.package_display H3.package_name {
    border: none;
    margin-top: 0;
    margin-bottom: .5em;
    background-color: #D3D7CF;

    -webkit-transition: all .2s ease-out 0s;
    -moz-transition: all .2s ease-out 0s;
    -ms-transition: all .2s ease-out 0s;
    -o-transition: all .2s ease-out 0s;
    transition: all .2s ease-out 0s;    
}

DIV.package_display:hover H3.package_name {
    background-color: #729FCF;
}

DIV.package_display P {
    margin-top: 0;
    margin-bottom: 0;
}

A.package_name {
    /* display: block; */
    text-decoration: none;
}

A.package_group {
    /* display: block; */
    text-decoration: none;
    float: right;
    font-size: 50%;
    line-height: 166%;
    color: white;
}

DIV.package_display A.package_link, DIV.package_display A.download_link, DIV.package_display A.repository_link {
    color: black;
    font-weight: bold;
    font-size: 80%;
    display: inline-block;
    text-decoration: none;
    line-height: 22px;
    padding: .5em .5em .5em 26px;
    min-height: 22px;
    background-repeat: no-repeat;
    background-position: left center;
}

DIV.package_display A.download_link {
    padding-right: .65em;
}

DIV.package_display A.repository_link {
    padding-left: 30px;
}

DIV.package_display A.package_link {
    background-image: url("pkg-page.png");
}
DIV.package_display A.download_link {
    background-image: url("download.png");
}
DIV.package_display A.repository_link {
    background-image: url("repository.png");
}

h4.notice {
  font-weight: normal;
  font-size: 100%;
  color: black;
  font-style: italic;
}

p.error {
  font-weight: normal;
  font-size: 100%;
  color: red;
}
