## Copyright (C) 2014 Julien Bect <jbect@users.sourceforge.net>
##
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## Author: Julien Bect <julien.bect@supelec.fr>
## Created: 2014-09-01

function s = insert_char_entities (s)

  # This one has to be first
  #  (otherwise we would get, e.g.,  <  ==>  &lt;  ==>  &amp;lt;)
  s = regexprep (s, "&", "&amp;");

  s = regexprep (s, "<", "&lt;");
  s = regexprep (s, ">", "&gt;");

endfunction
