## Copyright (C) 2009 Soren Hauberg <soren@hauberg.org>
##
## This program is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## This program is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {Function File} find_package ()
## undocumented internal function
## @end deftypefn

function [package, found] = find_package (name)
  package = "octave";
  p = which (name);
  found = !isempty (p);
  l = pkg ("list");

  for k = 1:length (l)
    d = l{k}.dir;
    idx = strfind (p, d);
    if (numel (idx) == 1 && idx == 1)
      package = l{k}.name;
      break;
    endif
  endfor
endfunction
